package com.xinelu.manage.service.scriptinfonode;

import com.xinelu.manage.domain.scriptinfonode.ScriptInfoNode;

import java.util.List;

/**
 * 话术信息节点Service接口
 *
 * @author xinelu
 * @date 2024-06-12
 */
public interface IScriptInfoNodeService {
    /**
     * 查询话术信息节点
     *
     * @param id 话术信息节点主键
     * @return 话术信息节点
     */
    ScriptInfoNode selectScriptInfoNodeById(Long id);

    /**
     * 查询话术信息节点列表
     *
     * @param scriptInfoNode 话术信息节点
     * @return 话术信息节点集合
     */
    List<ScriptInfoNode> selectScriptInfoNodeList(ScriptInfoNode scriptInfoNode);

    /**
     * 新增话术信息节点
     *
     * @param scriptInfoNode 话术信息节点
     * @return 结果
     */
    int insertScriptInfoNode(ScriptInfoNode scriptInfoNode);

    /**
     * 修改话术信息节点
     *
     * @param scriptInfoNode 话术信息节点
     * @return 结果
     */
    int updateScriptInfoNode(ScriptInfoNode scriptInfoNode);

    /**
     * 批量删除话术信息节点
     *
     * @param ids 需要删除的话术信息节点主键集合
     * @return 结果
     */
    int deleteScriptInfoNodeByIds(Long[] ids);

    /**
     * 删除话术信息节点信息
     *
     * @param id 话术信息节点主键
     * @return 结果
     */
    int deleteScriptInfoNodeById(Long id);
}
